@@ -4,13 +4,14 @@ import (
 	"context"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestFsckCheck(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsFsckCheck(ctx))
 	assert.True(t, IsFsckCheck(WithFsckCheck(ctx, true)))
@@ -21,7 +22,7 @@ func TestFsckCheck(t *testing.T) {
 func TestFsckForce(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsFsckForce(ctx))
 	assert.True(t, IsFsckForce(WithFsckForce(ctx, true)))
@@ -32,7 +33,7 @@ func TestFsckForce(t *testing.T) {
 func TestFsckFunc(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	ffunc := func(context.Context, string) bool {
 		return true
@@ -46,7 +47,7 @@ func TestFsckFunc(t *testing.T) {
 func TestCheckRecipientsCtx(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsCheckRecipients(ctx))
 	assert.True(t, IsCheckRecipients(WithCheckRecipients(ctx, true)))
