@@ -10,7 +10,7 @@ import (
 )
 
 // Fsck checks all stores/entries matching the given prefix.
-func (s *Store) Fsck(ctx context.Context, path string) error {
+func (s *Store) Fsck(ctx context.Context, store, path string) error {
 	var result []error
 
 	for alias, sub := range s.mounts {
@@ -18,6 +18,10 @@ func (s *Store) Fsck(ctx context.Context, path string) error {
 			continue
 		}
 
+		if store != "" && alias != store {
+			continue
+		}
+
 		if path != "" && !strings.HasPrefix(path, alias+"/") {
 			continue
 		}
@@ -25,17 +29,18 @@ func (s *Store) Fsck(ctx context.Context, path string) error {
 		path = strings.TrimPrefix(path, alias+"/")
 
 		// check sub store
-		debug.Log("Checking %s", alias)
+		debug.Log("Checking mount point %s", alias)
 
 		if err := sub.Fsck(ctx, path); err != nil {
 			out.Errorf(ctx, "fsck failed on sub store %s: %s", alias, err)
 			result = append(result, err)
 		}
 
-		debug.Log("Checked %s", alias)
+		debug.Log("Checked mount point %s", alias)
 	}
 
 	// check root store
+	debug.Log("Checking root store")
 	if err := s.store.Fsck(ctx, path); err != nil {
 		out.Errorf(ctx, "fsck failed on root store: %s", err)
 		result = append(result, err)
